+++
date = "2016-08-15T16:11:58+05:30"
title = "Releasing the mongocxx driver"
[menu.main]
  weight = 20
  parent="contributing"
+++

## Releasing the mongocxx driver

## Confirm Version Status in Jira

- Ensure that all tickets under the version to be released are in
  'Resolved' status on the C++ Driver [project
  page](https://jira.mongodb.org/browse/CXX/?selectedTab=com.atlassian.jira.jira-projects-plugin:versions-panel)

## Create a BUMP commit

This commit essentially removes the -pre (e.g. 1.0.0-rc79-pre ->
1.0.0-rc79) and creates what is considered the final commit in the release.

*  If you haven't already, clone the mongodb-cxx-driver repository

```
git clone git@github.com:mongodb/mongo-cxx-driver.git 
cd mongo-cxx-driver
```

* Otherwise, pull the latest code down from the origin with `git pull`
* Update the following files (changing version numbers to remove the "-pre"
  for the MONGOCXX_VERSION_EXTRA and BSONCXX_VERSION_EXTRA variables):
    * [`src/mongocxx/CMakeLists.txt`](https://github.com/mongodb/mongo-cxx-driver/blob/master/src/mongocxx/CMakeLists.txt#L30)
    * [`src/bsoncxx/CMakeLists.txt`](https://github.com/mongodb/mongo-cxx-driver/blob/master/src/bsoncxx/CMakeLists.txt#L22) 
* Commit with message "BUMP rx.y.z[-rcq]", e.g.:

```
git commit -am "BUMP r3.0.1"
git push origin master
```

Pushing the BUMP commit to the origin will kick off builds in Evergreen,
Travis CI and AppVeyor (which handles Windows builds). Wait for all three
builds to finish and pass, re-running any timeout/spot failures.

## Tag the Release

* Create an tag for the commit that will serve as the release (or release candidate), eg:

```
git tag r3.0.1
git push origin r3.0.1
```

## Draft & Publish GitHub Release Notes

* Hit up the [GitHub releases
  page](https://github.com/mongodb/mongo-cxx-driver/releases)
* Copy the previous announcement and modify with release-specific information
    * The "Known Issues", "Bug", and "Improvement" sections are generated by JIRA. Click on the specific version of the [C++ Driver Project](https://jira.mongodb.org/browse/CXX/?selectedTab=com.atlassian.jira.jira-projects-plugin:versions-panel) and on the version Summary page there is a link for "Release Notes" where you can copy the HTML and paste it into the GitHub Release Notes markdown.
* Draft and publish a new release against the tag you just pushed

## Release the Version in Jira 

* Go
  [here](https://jira.mongodb.org/plugins/servlet/project-config/CXX/versions)
* Close all the the Resolved tickets via a [bulk transition](https://confluence.atlassian.com/jira/modifying-multiple-bulk-issues-185729606.html)
* Click the cog next to the version you are about to release and select "Release"
* Follow the dialogs/wizards and whatnot, setting the release date to the current date

## Generate and Publish Documentation

Documentation generation must be run after the release tag has been made
and pushed.

* Edit `etc/apidocmenu.md` and add the released version in the 'mongocxx'
  column following the established pattern.  If this is a major release,
  revise the entire document as needed.  If revised substantially, also
  edit `docs/content/index.md` to match.

* Edit `etc/generate-all-apidocs.pl` and add the new release version to
  the `@DOC_TAGS` array, following the established pattern.

* Edit `docs/content/mongocxx-v3/installation.md` and update `Step 3` to
  reflect the latest version to download.  (Generally, search for the last
  version number and update it.)

* Commit these changes.

`git commit -am "Prepare to generate r3.0.2 release documentation"`

* Ensure you have `doxygen` and `hugo` installed and up to date.

* Change to the repo top directory and run `git clean -dxf` to clear out
  all extraneous files.

* Change to the `build` directory and run cmake as you usually would.

* To test documentation generation without deploying, run the `docs` build
  target.  E.g. `ninja docs`.  If this works, your documentation tools are
  correctly installed.  Note that this only generates hugo docs and a
  single set of doxygen docs for the current repo.  To test generation of
  all docs for all tags, use the `doxygen-all` target and be prepared to
  wait a while.

* To generate and deploy documentation to GitHub Pages, execute both the
  `hugo-deploy` and `doxygen-deploy` targets.  The doxygen build will take
  a long time.

* Check out the "gh-pages" branch and `git pull` the deployed docs.

* Update the api/mongocxx-v3 symlink to point to the newly released
  version.  If a major version bump has occurred, revise the symlink
  structure as needed.  Make sure 'current' always points to a *symlink*
  tracking the latest release branch.

* Commit and push the symlink change.

`git commit -am "Update symlink for r3.0.3"`

* Wait a minute and verify the docs site has been updated.

* Return to the original branch.

## Create the Next Version commit

* Update the following files (changing version numbers to bump to the next version number and add the "-pre" suffix for the MONGOCXX_VERSION_EXTRA and BSONCXX_VERSION_EXTRA variables):
    * [`src/mongocxx/CMakeLists.txt`](https://github.com/mongodb/mongo-cxx-driver/blob/master/src/mongocxx/CMakeLists.txt#L30)
    * [`src/bsoncxx/CMakeLists.txt`](https://github.com/mongodb/mongo-cxx-driver/blob/master/src/bsoncxx/CMakeLists.txt#L22) 
* Commit with message "post rx.y.z[-rcq]", e.g.:

```
git commit -am "post r3.0.1"
git push origin master
```

## Email Google Groups

* Send it to mongodb-announce@googlegroups.com AND mongodb-user@googlegroups.com
* Template:

> The MongoDB C++ Driver Team is very excited to announce the availability of version X.Y.Z of the new MongoDB C++11 driver.
> We are not promising API or ABI stability until the 3.1.0 release so that we can meaningfully incorporate user feedback after the 3.0.0 GA. We will make every effort to minimize API changes.  The new driver is incompatible with the prior legacy, 26compat, and server C++ drivers.
>
> You can obtain the source for the new driver from GitHub, either under the rX.Y.Z tag or from the releases page. General documentation for the new driver is available on the github wiki. Doxygen API documentation is also available.
>
> Please feel free to post any questions to the mongodb-user mailing list. Bug reports should be filed against the CXX project in the MongoDB JIRA. If you are interested in participating in the development of the C++11 driver, questions should be sent to the mongodb-dev mailing list. Github pull requests are welcome, and should be issued against the master branch of the repository, where the C++11 driver is developed.
> We look forward to hearing from you. Happy C++11’ing!
>
> Thank You,
> The MongoDB C++ Driver Team

